<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [
  <!ENTITY copy "&#169;">
  <!ENTITY nbsp "&#160;">
  <!ENTITY lk "/webcenter_page/user_lang_key">
]>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:Lang="com.esko.webcenter.jsp.LanguageMgr" exclude-result-prefixes="Lang">

  <!-- 

       Template that generates annotation table for all pages

  -->
  <xsl:template name="AnnotationList">  
	<xsl:variable name="pageCount">
		<xsl:call-template name="pageCount"/>
	</xsl:variable>	

	
	<xsl:for-each select="xfdf">
		<xsl:if test="count(annots/*[string-length(@inreplyto)+string-length(@linkedto) = 0]) &gt; 0">
			<xsl:variable name="pageNumber">
				<xsl:choose>
					<xsl:when test="$pageCount &gt; 0"><xsl:value-of select="./@pageNumber"/></xsl:when>
					<xsl:otherwise><xsl:value-of select="0"/></xsl:otherwise>
				</xsl:choose>		
			</xsl:variable>
			<xsl:variable name="selectedVersionID">
				<xsl:choose>
					<xsl:when test="$pageCount &gt; 0"><xsl:value-of select="./@docVersionID"/></xsl:when>
					<xsl:otherwise><xsl:value-of select="/webcenter_page/doc_version/@id"/></xsl:otherwise>
				</xsl:choose>		
			</xsl:variable>
								
			<div class="wcr-table-section page-{$pageNumber}">
				<xsl:call-template name="AnnotationTable">
					<xsl:with-param name="selectedVersionID" select="$selectedVersionID"/>
					<xsl:with-param name="pageNumber" select="$pageNumber"/>
				</xsl:call-template>
				<div class="no-results no-annotations-found hidden"><xsl:value-of select="Lang:getStr(&lk;,'ERRNOITEMSFOUND')"/></div>
				<script type="text/javascript">
					(function(){
					var currentSection = $(".wcr-table-section.page-<xsl:value-of select="$pageNumber"/>");
					if ($("tr.ann-row", currentSection).length === 0){
						$(".no-annotations-found", currentSection).removeClass("hidden");
					}
					})();				
				</script>
			</div>		
			
			
			
			<xsl:if test="$pageNumber != '0'">
			<div class="wcr-table-footer">
            	<div class="wcr-table-paging">
            		<div class="wcr-pager">
            			 <input name="annotationpaging" id="annotationpaging"  type="text" class="form-control" >
							 <xsl:attribute name="value">
							 	<xsl:value-of select="Lang:getStr(&lk;,'PAGE')"/>&nbsp;<xsl:value-of select="$pageNumber"/>&nbsp;<xsl:value-of select="Lang:getStr(&lk;,'OF')"/>&nbsp;<xsl:value-of select="$pageCount"/>
							 </xsl:attribute>
						 </input>
					</div>
				</div>
			</div>				
			</xsl:if>	
		</xsl:if>
	</xsl:for-each>
  </xsl:template>	

	 <xsl:template name="miniviewer">
 		<xsl:param name="maxPixSize"/>
	 	<xsl:param name="reportStyle"/>
	 	<xsl:param name="groupLinkedAnnotations"/>		
	 	<xsl:param name="userColors"/>
	 
	 	
		<xsl:if test="($reportStyle = 1 or $reportStyle = 2)">
			<td class="non-interactive-mini-viewer">
				<div class="mini-viewer" style="width: {$maxPixSize}px; height:{$maxPixSize}px">
					<div class="viewerApp">
						<xsl:attribute name="id"><xsl:value-of select="@name"></xsl:value-of>_zoomedIn</xsl:attribute>
					</div>
					<div class="input-blocker" style="width: {$maxPixSize}px; height:{$maxPixSize}px"/>
				</div>										
			</td>
		</xsl:if>
		<xsl:if test="$reportStyle = 2">
			<td class="non-interactive-mini-viewer">
				<div class="mini-viewer" style="width: {$maxPixSize}px; height:{$maxPixSize}px">
					<div class="viewerApp">
						<xsl:attribute name="id"><xsl:value-of select="@name"></xsl:value-of></xsl:attribute>
					</div>	
					<div class="input-blocker" style="width: {$maxPixSize}px; height:{$maxPixSize}px"/>
				</div>				
			</td>
		</xsl:if>
		<script>
			require(["web-viewer-wcr/webcenter/App"], function(ViewerApp) {
				var WebCenterConfig = ViewerApp.Config;
            	var WebCenterUser = ViewerApp.User;
				var docVerId = "<xsl:value-of select="../../@docVersionID"/>";
				var pageIndex = "<xsl:value-of select="../../@pageIndex"/>";
				var annotationName = "<xsl:call-template name="encodejs"><xsl:with-param name="string" select="@name" /></xsl:call-template>";												
				
				var user = new WebCenterUser(gCurrentUser.userID,
				gCurrentUser.userName,
				gCurrentUser.firstName,
				gCurrentUser.lastName,
				gCurrentUser.lang,
				gCurrentUser.isAdmin);
				
				
				var navigationThumbnailCtx = $("#<xsl:call-template name="encodejs"><xsl:with-param name="string" select="@name" /></xsl:call-template>");												
				if(navigationThumbnailCtx){
					var config = new WebCenterConfig("", "view/", user);												
					config.set("ViewerCore.layouttype", "minimal");
					config.set("AnnotationModel.annotationFilter", {
						resetFilter: true,
						allowedAnnotations: [{
							name: annotationName,
							allowLinkedAnnotations: <xsl:value-of select="$groupLinkedAnnotations"/>
						}]
					});
					config.set("AnnotationModel.hideAllPopups", true);
					config.set("WebCenterUser.disablePersistOptions", true);
					<xsl:if test="$userColors != 1">
					config.set("forceAnnotationColor", '#ff0000');
					</xsl:if>
					config.set("WebCenterDataAdapter.pageIndex", pageIndex);
					config.addCustomModule("annotation");
					
					new ViewerApp(navigationThumbnailCtx, docVerId, config);
				}
				
				var zoomedInThumbnailCtx = $("#<xsl:call-template name="encodejs"><xsl:with-param name="string" select="@name" /></xsl:call-template>_zoomedIn");
				if(zoomedInThumbnailCtx){
					var configZoomedIn = new WebCenterConfig("", "view/", user);											
					configZoomedIn.set("ViewerCore.layouttype", "minimal");
					configZoomedIn.set("AnnotationModel.annotationFilter", {
						resetFilter: true,
						allowedAnnotations: [{
							name: annotationName,
							allowLinkedAnnotations: <xsl:value-of select="$groupLinkedAnnotations"/>
						}]
					});
					
					configZoomedIn.set("AnnotationModel.hideAllPopups", true);
					<xsl:if test="$userColors != 1">
					configZoomedIn.set("forceAnnotationColor", '#ff0000');
					</xsl:if>
					configZoomedIn.set("AnnotationModel.zoom", {
						annotationName: annotationName,
						animation: false,
						select: false
					});			
					configZoomedIn.set("WebCenterUser.disablePersistOptions", true);
					configZoomedIn.set("WebCenterDataAdapter.pageIndex", pageIndex);
					configZoomedIn.addCustomModule("annotation");
	
					new ViewerApp(zoomedInThumbnailCtx, docVerId, configZoomedIn);												
				}
				
			});									
		</script>
	 </xsl:template>
  <!-- 

       Template that generates annotation table

  -->
  <xsl:template name="AnnotationTable">  
	<xsl:param name="selectedVersionID"/>
	<xsl:param name="pageNumber" select="0"/>	

	<xsl:variable name="pageIndex">
		<xsl:choose>
			<xsl:when test="$pageNumber = '0'">0</xsl:when>
			<xsl:otherwise><xsl:value-of select="number($pageNumber) - 1"/></xsl:otherwise>
		</xsl:choose>
	</xsl:variable>	

	<xsl:variable name="pageCount">
		<xsl:call-template name="pageCount"/>
	</xsl:variable>	

	<xsl:variable name="reportStyle">
		<xsl:call-template name="reportStyle"/>
	</xsl:variable>

	<xsl:variable name="maxPixSize">
		<xsl:call-template name="maxPixSize"/>
	</xsl:variable>

	<xsl:variable name="userColors">
		<xsl:call-template name="userColors"/>
	</xsl:variable>
	
	<xsl:variable name="reviewState">
		<xsl:call-template name="reviewState"/>
	</xsl:variable>	

	<xsl:variable name="userName">
		<xsl:call-template name="userName"/>
	</xsl:variable>	
	
	<xsl:variable name="showUser">
		<xsl:call-template name="showUser"/>
	</xsl:variable>

	<xsl:variable name="debug"> <!-- set to 1 to get debug info in page -->
		<xsl:call-template name="debug"/>
	</xsl:variable>

	<table class="ordtable table-align-top">
		<thead>
			<tr>
				<th>#</th>
				<xsl:if test="$reportStyle != 0">			
					<th><xsl:value-of select="Lang:getStr(&lk;, 'VIEW')"/></th>
				</xsl:if>
				<xsl:if test="$hasTimestamp = 1">
					<th><xsl:value-of select="Lang:getStr(&lk;, 'TIMESTAMP')"/></th>
				</xsl:if>
				
				<th/>
				<th><xsl:value-of select="Lang:getStr(&lk;, 'ACTIONHIST_COMMENT')"/></th> 
				<th><xsl:value-of select="Lang:getStr(&lk;, 'ANNOTATION_CREATOR')"/></th>
				<th class="td-date"><xsl:value-of select="Lang:getStr(&lk;, 'DATECREATED')"/></th>
				<th class="td-date"><xsl:value-of select="Lang:getStr(&lk;, 'DATEMODIFIED')"/></th>
			</tr>
		</thead>
		<tbody>
			<xsl:for-each select="annots/*">
				<xsl:sort data-type="number" select="substring-before(./@title, ' ')" order="ascending"/>
				<xsl:if test="string-length(./@inreplyto)=0 and string-length(./@linkedto)=0">
					<xsl:variable name="includeReviewState">
						<xsl:choose>
							<xsl:when test="$reviewState != '0'">
								<xsl:variable name="invert" select="starts-with($reviewState, 'NOT')"/>
								<xsl:variable name="reviewStateParam">
									<xsl:choose>
										<xsl:when test="$invert = 'true'"><xsl:value-of select="substring($reviewState, 5)"/></xsl:when>
										<xsl:otherwise><xsl:value-of select="$reviewState"/></xsl:otherwise>
									</xsl:choose>
								</xsl:variable>
								<xsl:variable name="invertParam">
									<xsl:choose>
										<xsl:when test="$invert = 'true'">1</xsl:when>
										<xsl:otherwise>0</xsl:otherwise>
									</xsl:choose>
								</xsl:variable>
								<xsl:variable name="reviewStateCountString"><xsl:call-template name="HasReviewStateRecursive"><xsl:with-param name="reviewState" select="$reviewStateParam"/><xsl:with-param name="invert" select="$invertParam"/></xsl:call-template></xsl:variable>
								<xsl:value-of select="string-length($reviewStateCountString) &gt; 0"/>
							</xsl:when>
							<xsl:otherwise><xsl:value-of select="true()"/></xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
					<xsl:variable name="includeUserName">
						<xsl:choose>
							<xsl:when test="$showUser != '0'">
								<xsl:call-template name="checkShowUsers"><xsl:with-param name="showUser" select="$showUser"/></xsl:call-template>
							</xsl:when>
							<xsl:when test="$userName != '0'">
								<xsl:variable name="userNameCountString"><xsl:call-template name="HasUserRecursive"><xsl:with-param name="checkedName" select="$userName"/></xsl:call-template></xsl:variable>
								<xsl:value-of select="string-length($userNameCountString) &gt; 0"/>
							</xsl:when>
							<xsl:otherwise><xsl:value-of select="true()"/></xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
					<xsl:if test="$includeReviewState = 'true' and $includeUserName = 'true'">
						<xsl:variable name="currentName" select="./@name"/>
						<xsl:variable name="replyCountString"><xsl:call-template name="ReplyCount"><xsl:with-param name="showUser" select="$showUser"/></xsl:call-template></xsl:variable>
						<xsl:variable name="replyCount"><xsl:value-of select="string-length($replyCountString)"/></xsl:variable>
						<xsl:variable name="currentRows">
							<xsl:choose>
								<xsl:when test="count(../*[@inreplyto=$currentName]) &gt; 0">
									<xsl:value-of select="$replyCount + 2"/>
								</xsl:when>
								<xsl:otherwise><xsl:value-of select="1"/></xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						<xsl:variable name="currentType">
							<xsl:choose>
								<xsl:when test="name(.) = 'square'">Rectangle</xsl:when>
								<xsl:when test="name(.) = 'circle'">Oval</xsl:when>
								<xsl:when test="name(.) = 'text'">Note</xsl:when>
								<xsl:when test="name(.) = 'ink'">Freehand</xsl:when>
								<xsl:when test="name(.) = 'line'">
									<xsl:choose>
										<xsl:when test="string-length(./@head) + string-length(./@tail) &gt; 0">Arrow</xsl:when>
										<xsl:otherwise>Line</xsl:otherwise>
									</xsl:choose>
								</xsl:when>
								<xsl:when test="name(.) = 'highlight'">Highlight</xsl:when>
								<xsl:otherwise>Unknown</xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						<xsl:variable name="currentUser" select="substring-after(./@title, ' ')"/>
						<tr class="ann-row">
							<td rowspan="{$currentRows}"><xsl:value-of select="substring-before(./@title, ' ')"/></td>
							<xsl:if test="$reportStyle != 0">	
								<xsl:choose>
									<xsl:when test="$viewableVector = 'true'">
										<!-- Group linked annotation when SVG viewfile is present and annotation type is 'highlight' -->
										<xsl:variable name="groupLinkedAnnotations">
											<xsl:value-of select="$viewableSVG = 'true' and local-name() = 'highlight'"/>
										</xsl:variable>
										<td rowspan="{$currentRows}">
											<table>
												<tr>
												 	<xsl:call-template name="miniviewer">
														 <xsl:with-param name="maxPixSize" select="$maxPixSize"/>
														 <xsl:with-param name="reportStyle" select="$reportStyle"/>
														 <xsl:with-param name="groupLinkedAnnotations" select="$groupLinkedAnnotations"/>
														 <xsl:with-param name="userColors" select="$userColors"/>
														 
													 </xsl:call-template>
												</tr>
												<!-- Linked annotations -->
												<xsl:if test="$groupLinkedAnnotations = 'false'">													
													<xsl:for-each select="../*[@linkedto=$currentName and string-length(@inreplyto)=0]">													
														<tr>
															<xsl:call-template name="miniviewer">
																 <xsl:with-param name="maxPixSize" select="$maxPixSize"/>
																 <xsl:with-param name="reportStyle" select="$reportStyle"/>
																 <xsl:with-param name="groupLinkedAnnotations" select="$groupLinkedAnnotations"/>
														 		<xsl:with-param name="userColors" select="$userColors"/>
																 
															 </xsl:call-template>
														</tr>		
													</xsl:for-each>
												</xsl:if>												
											</table>
										</td>
									</xsl:when>
									<xsl:when test="$viewableGraphics = 'true'">
										<td rowspan="{$currentRows}">
											<table>
												<tr>
													<xsl:call-template name="ImageRow">
														<xsl:with-param name="selectedVersionID" select="$selectedVersionID"/>
														<xsl:with-param name="pageIndex" select="$pageIndex"/>
														<xsl:with-param name="reportStyle" select="$reportStyle"/>
														<xsl:with-param name="maxPixSize" select="$maxPixSize"/>
														<xsl:with-param name="userColors" select="$userColors"/>
														<xsl:with-param name="debug" select="$debug"/>
													</xsl:call-template>
												</tr>
												<!-- Linked annotations -->
												<xsl:for-each select="../*[@linkedto=$currentName and string-length(@inreplyto)=0]">													
													<tr>
														<xsl:call-template name="ImageRow">
															<xsl:with-param name="selectedVersionID" select="$selectedVersionID"/>
															<xsl:with-param name="pageIndex" select="$pageIndex"/>
															<xsl:with-param name="reportStyle" select="$reportStyle"/>
															<xsl:with-param name="maxPixSize" select="$maxPixSize"/>
															<xsl:with-param name="userColors" select="$userColors"/>
															<xsl:with-param name="debug" select="$debug"/>
														</xsl:call-template>
													</tr>		
												</xsl:for-each>
											</table>
										</td>
									</xsl:when>
									<xsl:when test="./@thumbnail">
										<td rowspan="{$currentRows}">
											<table>
												<tr>
													<xsl:call-template name="ImageRow">
														<xsl:with-param name="selectedVersionID" select="$selectedVersionID"/>
														<xsl:with-param name="pageIndex" select="$pageIndex"/>
														<xsl:with-param name="reportStyle" select="$reportStyle"/>
														<xsl:with-param name="maxPixSize" select="$maxPixSize"/>
														<xsl:with-param name="userColors" select="$userColors"/>
														<xsl:with-param name="debug" select="$debug"/>
														<xsl:with-param name="detailedThumbnailSrc" select="./@detailed-thumbnail"/>
														<xsl:with-param name="thumbnailSrc" select="./@thumbnail"/>
														<xsl:with-param name="graphicWidth" select="/webcenter_page/romd/metadata/size/width * (25.4 div 96.0)" />
														<xsl:with-param name="graphicHeight" select="/webcenter_page/romd/metadata/size/height * (25.4 div 96.0)"/>
													</xsl:call-template>
													
													<xsl:for-each select="../*[@linkedto=$currentName and string-length(@inreplyto)=0]">
														<tr>
															<xsl:call-template name="ImageRow">
																<xsl:with-param name="selectedVersionID" select="$selectedVersionID"/>
																<xsl:with-param name="pageIndex" select="$pageIndex"/>
																<xsl:with-param name="reportStyle" select="$reportStyle"/>
																<xsl:with-param name="maxPixSize" select="$maxPixSize"/>
																<xsl:with-param name="userColors" select="$userColors"/>
																<xsl:with-param name="debug" select="$debug"/>
																<xsl:with-param name="detailedThumbnailSrc" select="./@detailed-thumbnail"/>
																<xsl:with-param name="thumbnailSrc" select="./@thumbnail"/>
																<xsl:with-param name="graphicWidth" select="/webcenter_page/romd/metadata/size/width * (25.4 div 96.0)" />
																<xsl:with-param name="graphicHeight" select="/webcenter_page/romd/metadata/size/height * (25.4 div 96.0)"/>
															</xsl:call-template>
														</tr>
													</xsl:for-each>
												</tr>
											</table>
										</td>
									</xsl:when>
									<xsl:otherwise>
										<td rowspan="{$currentRows}"><xsl:value-of select="Lang:getStr(&lk;, 'NOTVIEWABLE')"/></td>
									</xsl:otherwise>
								</xsl:choose>								
							</xsl:if>
							
							<xsl:if test="$hasTimestamp = 1">
							<td rowspan="{$currentRows}">
								<xsl:call-template name="secondsToUserFriendlyString">
									<xsl:with-param name="s" select="./@startTime"></xsl:with-param>
								</xsl:call-template> -
								<xsl:call-template name="secondsToUserFriendlyString">
									<xsl:with-param name="s" select="./@endTime"></xsl:with-param>
								</xsl:call-template>
							</td>
							</xsl:if>
							<td>
								<!--xsl:value-of select="($currentType)"/><br/-->
								<!-- xsl:value-of select="{name(.)}"/><br/-->								
								<i title="{$currentType} - {$currentUser}">
									<xsl:attribute name="class">
										<xsl:choose>
											<xsl:when test="name(.) = 'square'">icon icon-normal icon-WCR_Annotation-Rect icon-danger</xsl:when>
											<xsl:when test="name(.) = 'circle'">icon icon-normal icon-WCR_Annotation-Oval icon-danger</xsl:when>
											<xsl:when test="name(.) = 'text'">icon icon-normal icon-WCR_Annotation-Note-sub</xsl:when>
											<xsl:when test="name(.) = 'ink'">icon icon-normal icon-WCR_Annotation-Freehand icon-danger</xsl:when>
											<xsl:when test="name(.) = 'line'">
												<xsl:choose>
													<xsl:when test="string-length(./@head) + string-length(./@tail) &gt; 0">icon icon-normal icon-WCR_Annotation-Arrow icon-danger</xsl:when>
													<xsl:otherwise>icon icon-normal icon-WCR_Annotation-Line icon-danger</xsl:otherwise>
												</xsl:choose>
											</xsl:when>
											<xsl:when test="name(.) = 'highlight'">icon icon-normal icon-WCR_Annotation-Highlight-cont containerIcon</xsl:when>
											<xsl:otherwise>icon None</xsl:otherwise>
										</xsl:choose>
									</xsl:attribute>
									<xsl:if test="name(.) = 'highlight'">
										<i class="icon subIcon icon icon-WCR_Annotation-Highlight-sub icon-yellow"/>
									</xsl:if>
								</i>
							</td>
							<xsl:call-template name="TextRow">
								<xsl:with-param name="debug" select="$debug"/>
							</xsl:call-template>
						</tr>
						<!-- Reviews -->
						<xsl:call-template name="Replies">
							<xsl:with-param name="reviews" select="1"/>
							<xsl:with-param name="showUser" select="$showUser"/>
							<xsl:with-param name="startposition" select="0"/>
							<xsl:with-param name="debug" select="$debug"/>
						</xsl:call-template>
						<!-- Replies -->
						<xsl:call-template name="Replies">
							<xsl:with-param name="reviews" select="0"/>
							<xsl:with-param name="showUser" select="$showUser"/>
							<xsl:with-param name="startposition" select="0"/>
							<xsl:with-param name="debug" select="$debug"/>
						</xsl:call-template>
						<!-- Extra row to span remaining height with white background -->
						<xsl:if test="$currentRows &gt; 1">
							<tr>
								<td/>
								<!--  if there is an image part it will come here, but no td is needed as it is included in the rowspan of the image td -->
								<td colspan="5"/>
							</tr>
						</xsl:if>
					</xsl:if>
				</xsl:if>
			</xsl:for-each>
		</tbody>
	</table>
  </xsl:template>
  

  <!--
	
		Template that controls text part row; Called once for each annotation and reply
	
  -->
	<xsl:template name="TextRow">
		<xsl:param name="debug" select="0"/>		
		<td><xsl:copy-of select="./contents-richtext/body"/></td>
		<td><xsl:value-of select="substring-after(./@title, ' ')"/></td>
		<td class="td-date">
			<xsl:if test="debug = 1">
				<xsl:value-of select="./@creationdate"/><br/>
				<xsl:call-template name="GetTimestampFromXfdfDateString">
					<xsl:with-param name="DateString" select="./@creationdate"/>
				</xsl:call-template><br/>
			</xsl:if>
			<xsl:call-template name="HumanReadableLongDateAndTime">
				<xsl:with-param name="LongDateString">
					<xsl:call-template name="GetTimestampFromXfdfDateString">
						<xsl:with-param name="DateString" select="./@creationdate"/>
					</xsl:call-template>
				</xsl:with-param>
			</xsl:call-template>        								
		</td>
		<td class="td-date">
			<xsl:if test="debug = 1">
				<xsl:value-of select="./@date"/><br/>
				<xsl:call-template name="GetTimestampFromXfdfDateString">
					<xsl:with-param name="DateString" select="./@date"/>
				</xsl:call-template><br/>
			</xsl:if>
			<xsl:call-template name="HumanReadableLongDateAndTime">
				<xsl:with-param name="LongDateString">
					<xsl:call-template name="GetTimestampFromXfdfDateString">
						<xsl:with-param name="DateString" select="./@date"/>
					</xsl:call-template>
				</xsl:with-param>
			</xsl:call-template>        								
		</td>
	</xsl:template>
  

  <!--
	
		Template that counts the number of reviews with a given state (non-recursively) or any if reviewState param is 'Any' or not specified
	
  -->
	<!--  xsl:template name="HasReviewState">
		<xsl:param name="reviewState" select="'Any'"/>
		<xsl:param name="stateModel" select="'Review'"/>
		
		<xsl:variable name="currentName" select="./@name"/>
		<xsl:choose>		
			<xsl:when test="$reviewState = 'Any'">
				<xsl:value-of select="count(../*[@inreplyto=$currentName and @statemodel=$stateModel])"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="count(../*[@inreplyto=$currentName and @statemodel=$stateModel and @state=$reviewState])"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template -->
  
  <!--
	
		Template that counts the number of reviews with a given state (non-recursively) or any if reviewState param is 'Any'
	
  -->
	<xsl:template name="HasReviewStateRecursive">
		<xsl:param name="reviewState" select="'Any'"/>
		<xsl:param name="invert" select="0"/>		
		<xsl:variable name="stateModel" select="'Review'"/>
		<xsl:variable name="currentName" select="./@name"/>
		<xsl:choose>		
			<xsl:when test="$invert = '0' and $reviewState = 'Any' and count(../*[@inreplyto=$currentName and @statemodel=$stateModel]) &gt; 0">+</xsl:when>
			<xsl:when test="$invert = '0' and count(../*[@inreplyto=$currentName and @statemodel=$stateModel and @state=$reviewState]) &gt; 0">+</xsl:when>
			<xsl:when test="$invert = '1' and $reviewState = 'Any' and count(../*[@inreplyto=$currentName and @statemodel=$stateModel]) &gt; 0"></xsl:when>
			<xsl:when test="$invert = '1' and count(../*[@inreplyto=$currentName and @statemodel=$stateModel and @state=$reviewState]) &gt; 0"></xsl:when>
			<xsl:when test="$invert = '1'">+</xsl:when>
			<xsl:otherwise></xsl:otherwise>
		</xsl:choose>
		<xsl:if test="$invert='0'"> <!--  not recursive if invert -->
			<xsl:for-each select="../*[@inreplyto=$currentName]"><xsl:call-template name="HasReviewStateRecursive">
				<xsl:with-param name="reviewState" select="$reviewState"/>
				<xsl:with-param name="invert" select="$invert"/>		
			</xsl:call-template></xsl:for-each>
		</xsl:if>
	</xsl:template>
  
  <!--
	
		Template that check if the specified checkedName matches the annotation userName - 'Any' matches all
		Returns 1 character if match, otherwise 0
	
  -->
	<xsl:template name="HasUser">
		<xsl:param name="checkedName" select="'Any'"/>
		<xsl:variable name="loginNamePart">(<xsl:value-of select="$checkedName"/>)</xsl:variable>
		<xsl:variable name="userName" select="substring-after(./@title, ' ')"/>
		<xsl:choose>
			<xsl:when test="$checkedName = 'Any'">+</xsl:when>
			<xsl:when test="$checkedName = $userName">+</xsl:when>
			<xsl:when test="contains($userName,$loginNamePart)">+</xsl:when>
			<xsl:otherwise></xsl:otherwise>
		</xsl:choose>
	</xsl:template>
  
  
  <!--
	
		Template that counts (recursive) the number of matching checkedNames
	
  -->
	<xsl:template name="HasUserRecursive">
		<xsl:param name="checkedName" select="'Any'"/>
		<xsl:variable name="currentName" select="./@name"/>
		<xsl:call-template name="HasUser">
			<xsl:with-param name="checkedName" select="$checkedName"/>
		</xsl:call-template>
		<xsl:for-each select="../*[@inreplyto=$currentName]"><xsl:call-template name="HasUserRecursive">
			<xsl:with-param name="checkedName" select="$checkedName"/>
		</xsl:call-template></xsl:for-each>
	</xsl:template>
	
  <!--
	
		Template that checks if the current annotation (current context) author complies to the users defined in showUser
	
  -->	
	<xsl:template name="checkShowUsers">
		<xsl:param name="showUser" select="0"/>
		<xsl:variable name="userName" select="substring-after(./@title, ' ')"/>
		<xsl:choose>
			<xsl:when test="$showUser != '0'">		
				<xsl:value-of select="count(/webcenter_page/show_users/*[text()=$userName or contains($userName,concat('(', text(), ')'))]) &gt; 0">
				</xsl:value-of>
			</xsl:when>
			<xsl:otherwise><xsl:value-of select="true()"/></xsl:otherwise>
		</xsl:choose>
	</xsl:template>
  
  <!--
	
		Template that counts (recursive) Replies by appending a character for each result
	
  -->
	<xsl:template name="ReplyCount">
		<xsl:param name="showUser" select="0"/>
		<xsl:variable name="currentName" select="./@name"/>
		<xsl:for-each select="../*[@inreplyto=$currentName]">
			<xsl:variable name="annotCompliesToShowUser"><xsl:call-template name="checkShowUsers"><xsl:with-param name="showUser" select="$showUser"/></xsl:call-template></xsl:variable>
			<xsl:if test="$annotCompliesToShowUser = 'true'">+<xsl:call-template name="ReplyCount"><xsl:with-param name="showUser" select="$showUser"/></xsl:call-template></xsl:if>
		</xsl:for-each>
	</xsl:template>
  
  <!--
	
		Template that controls Replies part row; Called once for each annotation and reply
	
  -->
	<xsl:template name="Replies">
		<xsl:param name="reviews"/>
		<xsl:param name="depth" select="1"/>
		<xsl:param name="startposition" select="0"/>
		<xsl:param name="debug" select="0"/>
		<xsl:param name="showUser" select="0"/>
		
		<xsl:variable name="currentName" select="./@name"/>
		<xsl:variable name="currentUser" select="substring-after(./@title, ' ')"/>
		
		<xsl:for-each select="../*[@inreplyto=$currentName]">
			<xsl:variable name="annotCompliesToShowUser"><xsl:call-template name="checkShowUsers"><xsl:with-param name="showUser" select="$showUser"/></xsl:call-template></xsl:variable>
			<xsl:sort data-type="string" select="./@creationdate" order="ascending"/>
			<xsl:variable name="isReview"><xsl:value-of select="(./@statemodel = 'Review') and (string-length(./@state) &gt; 0)"/></xsl:variable>
			<xsl:if test="($annotCompliesToShowUser = 'true' and ($reviews = '1') and ($isReview = 'true')) or ($annotCompliesToShowUser = 'true' and ($reviews = '0') and ($isReview != 'true'))">
				<tr>
					
					<td> <!-- indent icons according to reply level -->
						<xsl:choose>
							<xsl:when test="(./@statemodel = 'Review') and (string-length(./@state) &gt; 0)">
								<!--xsl:value-of select="./@statemodel"/><br/-->
								<!--xsl:value-of select="./@state"/><br/-->								
								<i title="{./@state} - {$currentUser}">
									<xsl:attribute name="class">
										<xsl:choose>
											<xsl:when test="./@state = 'None'">icon None</xsl:when>
											<xsl:when test="./@state = 'Accepted'">icon icon-normal icon-WCR_Approved icon-green</xsl:when>
											<xsl:when test="./@state = 'Rejected'">icon icon-normal icon-WCR_Rejected icon-red</xsl:when>
											<xsl:when test="./@state = 'Cancelled'">icon icon-normal icon-WCR_Canceled icon-red</xsl:when>
											<xsl:when test="./@state = 'Completed'">icon icon-normal icon-WCR_Approve WCR_Completed</xsl:when>
											<xsl:otherwise>icon None</xsl:otherwise>
										</xsl:choose>										
									</xsl:attribute>
								</i>
							</xsl:when>
							<xsl:otherwise><i title="Reply - {$currentUser}" class="icon icon-normal icon-WCR_Annotation-Reply"/></xsl:otherwise>
						</xsl:choose>
					</td>
					<xsl:call-template name="TextRow">
						<xsl:with-param name="debug" select="$debug"/>
					</xsl:call-template>
				</tr>
				<!-- Reviews -->
				<xsl:call-template name="Replies">
					<xsl:with-param name="reviews" select="1"/>
					<xsl:with-param name="showUser" select="$showUser"/>
					<xsl:with-param name="startposition" select="$startposition + position()"/>
					<xsl:with-param name="depth" select="number($depth) + 1"/>
					<xsl:with-param name="debug" select="$debug"/>
				</xsl:call-template>
				<!-- Replies -->
				<xsl:call-template name="Replies">
					<xsl:with-param name="reviews" select="0"/>
					<xsl:with-param name="showUser" select="$showUser"/>
					<xsl:with-param name="startposition" select="$startposition + position()"/>
					<xsl:with-param name="depth" select="number($depth) + 1"/>
					<xsl:with-param name="debug" select="$debug"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>
		
  <!--
	
		Template that controls image part row; Called once for each (linked) annotation
	
  -->
	<xsl:template name="ImageRow">
		<xsl:param name="selectedVersionID"/>
		<xsl:param name="reportStyle" select="0"/>
		<xsl:param name="maxPixSize" select="100"/>
		<xsl:param name="userColors" select="0"/>
		<xsl:param name="pageIndex" select="0"/>
		<xsl:param name="debug" select="0"/>
		<xsl:param name="detailedThumbnailSrc"/>
		<xsl:param name="thumbnailSrc"/>
		<xsl:param name="graphicWidth"/>
		<xsl:param name="graphicHeight"/>
		
		<xsl:variable name="maxRes">
			<xsl:choose>
				<xsl:when test="$detailedThumbnailSrc"><xsl:value-of select="999" /></xsl:when>
				<xsl:otherwise><xsl:value-of select="360.0 div 25.4" /></xsl:otherwise> <!--  do not enlarge above this resolution (l/mm) -->
			</xsl:choose>
		</xsl:variable>
		
		<xsl:variable name="zoomRectMarginFraction" select="0.2"/> <!--  20% of widest dimension on each side -->
		
		<xsl:variable name="sessionID">
			<xsl:call-template name="sessionID"/>
		</xsl:variable>	

		<xsl:variable name="maxOfWidthAndHeight">
			<xsl:choose>
				<xsl:when test="$graphicWidth &gt; $graphicHeight"><xsl:value-of select="$graphicWidth" /></xsl:when>
				<xsl:otherwise><xsl:value-of select="$graphicHeight" /></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="romdElement" select="/webcenter_page/romd[@pageIndex=$pageIndex]"/>
		<xsl:variable name="trimmedHeightMM">
			<xsl:choose>
				<xsl:when test="$graphicHeight">
					<xsl:value-of select="$graphicHeight" />
				</xsl:when>
				<xsl:when test="$romdElement/webcenter_graphic_data/graphic_height/.">
					<xsl:value-of select="$romdElement/webcenter_graphic_data/graphic_height" as="xs:double" />
				</xsl:when>
				<xsl:when test="$romdElement/webcenter_graphic_data/pageranges/pagerange[index = $pageIndex]/graphic_height/.">
					<xsl:value-of select="$romdElement/webcenter_graphic_data/pageranges/pagerange[index = $pageIndex]/graphic_height" as="xs:double" />
				</xsl:when>
				<xsl:when test="$viewable3D = 'true'">
					<xsl:value-of select="100" as="xs:double"/>
				</xsl:when>
			</xsl:choose>			
		</xsl:variable>
		<xsl:variable name="trimmedWidthMM">
			<xsl:choose>
				<xsl:when test="$graphicWidth">
					<xsl:value-of select="$graphicWidth" />
				</xsl:when>
				<xsl:when test="$romdElement/webcenter_graphic_data/graphic_width/.">
					<xsl:value-of select="$romdElement/webcenter_graphic_data/graphic_width" as="xs:double" />
				</xsl:when>
				<xsl:when test="$romdElement/webcenter_graphic_data/pageranges/pagerange[index = $pageIndex]/graphic_width/.">
					<xsl:value-of select="$romdElement/webcenter_graphic_data/pageranges/pagerange[index = $pageIndex]/graphic_width" as="xs:double" />
				</xsl:when>
				<xsl:when test="$viewable3D = 'true'">
					<xsl:value-of select="100" as="xs:double"/>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="graphicMarginTopMM">
			<xsl:choose>
				<xsl:when test="$graphicHeight">
					<xsl:value-of select="($maxOfWidthAndHeight - $graphicHeight) div 2" />
				</xsl:when>
				<xsl:when test="$romdElement/webcenter_graphic_data/graphic_margintop/."><xsl:value-of select="$romdElement/webcenter_graphic_data/graphic_margintop" as="xs:double"/></xsl:when>
				<xsl:when test="$romdElement/webcenter_graphic_data/pageranges/pagerange[index = $pageIndex]/graphic_margintop/.">
					<xsl:value-of select="$romdElement/webcenter_graphic_data/pageranges/pagerange[index = $pageIndex]/graphic_margintop" as="xs:double" />
				</xsl:when>
				<xsl:when test="$viewable3D = 'true' and ./@view3dversion='1'">
					<xsl:value-of select="-50" as="xs:double"/>
				</xsl:when>
				<xsl:otherwise><xsl:value-of select="0" as="xs:double"/></xsl:otherwise>
			</xsl:choose> 		
		</xsl:variable>
		<xsl:variable name="graphicMarginLeftMM">
			<xsl:choose>
				<xsl:when test="$graphicWidth">
					<xsl:value-of select="($maxOfWidthAndHeight - $graphicWidth) div 2" />
				</xsl:when>
				<xsl:when test="$romdElement/webcenter_graphic_data/graphic_marginleft/."><xsl:value-of select="$romdElement/webcenter_graphic_data/graphic_marginleft" as="xs:double"/></xsl:when>
				<xsl:when test="$romdElement/webcenter_graphic_data/pageranges/pagerange[index = $pageIndex]/graphic_marginleft/.">
					<xsl:value-of select="$romdElement/webcenter_graphic_data/pageranges/pagerange[index = $pageIndex]/graphic_marginleft" as="xs:double" />
				</xsl:when>
				<xsl:when test="$viewable3D = 'true' and ./@view3dversion='1'">
					<xsl:value-of select="50" as="xs:double"/>
				</xsl:when>
				<xsl:otherwise><xsl:value-of select="0" as="xs:double"/></xsl:otherwise>
			</xsl:choose> 		
		</xsl:variable>
		<xsl:variable name="graphicMarginBottomMM">
			<xsl:choose>
				<xsl:when test="$graphicHeight">
					<xsl:value-of select="($maxOfWidthAndHeight - $graphicHeight) div 2" />
				</xsl:when>
				<xsl:when test="$romdElement/webcenter_graphic_data/graphic_marginbottom/."><xsl:value-of select="$romdElement/webcenter_graphic_data/graphic_marginbottom" as="xs:double"/></xsl:when>
				<xsl:otherwise><xsl:value-of select="0" as="xs:double"/></xsl:otherwise>
				<xsl:when test="$romdElement/webcenter_graphic_data/pageranges/pagerange[index = $pageIndex]/graphic_marginbottom/.">
					<xsl:value-of select="$romdElement/webcenter_graphic_data/pageranges/pagerange[index = $pageIndex]/graphic_marginbottom" as="xs:double" />
				</xsl:when>
				<xsl:when test="$viewable3D = 'true' and ./@view3dversion='1'">
					<xsl:value-of select="50" as="xs:double"/>
				</xsl:when>
			</xsl:choose> 		
		</xsl:variable>
		<xsl:variable name="graphicMarginRightMM">
			<xsl:choose>
				<xsl:when test="$graphicWidth">
					<xsl:value-of select="($maxOfWidthAndHeight - $graphicWidth) div 2" />
				</xsl:when>
				<xsl:when test="$romdElement/webcenter_graphic_data/graphic_marginright/."><xsl:value-of select="$romdElement/webcenter_graphic_data/graphic_marginright" as="xs:double"/></xsl:when>
				<xsl:otherwise><xsl:value-of select="0" as="xs:double"/></xsl:otherwise>
				<xsl:when test="$romdElement/webcenter_graphic_data/pageranges/pagerange[index = $pageIndex]/graphic_marginright/.">
					<xsl:value-of select="$romdElement/webcenter_graphic_data/pageranges/pagerange[index = $pageIndex]/graphic_marginright" as="xs:double" />
				</xsl:when>
				<xsl:when test="$viewable3D = 'true' and ./@view3dversion='1'">
					<xsl:value-of select="-50" as="xs:double"/>
				</xsl:when>
			</xsl:choose> 		
		</xsl:variable>
		<xsl:variable name="graphicHeightMM" select="$trimmedHeightMM + $graphicMarginTopMM + $graphicMarginBottomMM"/>
		<xsl:variable name="graphicWidthMM" select="$trimmedWidthMM + $graphicMarginLeftMM + $graphicMarginRightMM"/>
		
		<xsl:variable name="srcUrl1">
		
		<xsl:choose>
			<xsl:when test="$thumbnailSrc">
				<xsl:value-of select="$thumbnailSrc"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="concat('DownloadViewerThumbnail.jsp;jsessionid=',$sessionID,'?docversionid=',$selectedVersionID,'&amp;pix=',$maxPixSize,'&amp;pageno=',$pageIndex,'&amp;ajax=1')"/>
			</xsl:otherwise>
		</xsl:choose>
		</xsl:variable>
		
						
		<xsl:variable name="annotRect" select="concat(./@rect,./@coords)" as="xs:string"/> <!-- will only have one of the two -->
		<!-- min-x, min-y (, max-x, max-y) in points from lower left margin -->   
		<xsl:variable name="annotRect1" select="substring-before($annotRect,',')"/>
		<xsl:variable name="annotRect2" select="substring-before(substring-after($annotRect,','),',')"/>
		<xsl:variable name="annotRect3" select="substring-before(substring-after(substring-after($annotRect,','),','),',')"/>
		<xsl:variable name="annotRect4" select="substring-after(substring-after(substring-after($annotRect,','),','),',')"/>
		<xsl:variable name="annotRect1PT" select="$annotRect1" as="xs:double"/>
		<xsl:variable name="annotRect2PT" select="$annotRect2" as="xs:double"/>
		<xsl:variable name="annotRect3PT" select="$annotRect3" as="xs:double"/>
		<xsl:variable name="annotRect4PT" select="$annotRect4" as="xs:double"/>
		<xsl:variable name="annotRect1MM" select="$graphicMarginLeftMM + (($annotRect1PT * 25.4) div 72.0)"/>
		<xsl:variable name="annotRect2MM" select="$graphicHeightMM - $graphicMarginBottomMM - (($annotRect2PT * 25.4) div 72.0)"/>
		<xsl:variable name="annotRect3MM" select="$graphicMarginLeftMM + (($annotRect3PT * 25.4) div 72.0)"/>
		<xsl:variable name="annotRect4MM" select="$graphicHeightMM - $graphicMarginBottomMM - (($annotRect4PT * 25.4) div 72.0)"/>
		<xsl:variable name="annotRectXMinMM">
			<xsl:choose>
				<xsl:when test="$annotRect1MM &lt; $annotRect3MM"><xsl:value-of select="$annotRect1MM"/></xsl:when>
				<xsl:otherwise><xsl:value-of select="$annotRect3MM"/></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="annotRectYMinMM">
			<xsl:choose>
				<xsl:when test="$annotRect2MM &lt; $annotRect4MM"><xsl:value-of select="$annotRect2MM"/></xsl:when>
				<xsl:otherwise><xsl:value-of select="$annotRect4MM"/></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="annotRectXMaxMM">
			<xsl:choose>
				<xsl:when test="$annotRect1MM &gt; $annotRect3MM"><xsl:value-of select="$annotRect1MM"/></xsl:when>
				<xsl:otherwise><xsl:value-of select="$annotRect3MM"/></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="annotRectYMaxMM">
			<xsl:choose>
				<xsl:when test="$annotRect2MM &gt; $annotRect4MM"><xsl:value-of select="$annotRect2MM"/></xsl:when>
				<xsl:otherwise><xsl:value-of select="$annotRect4MM"/></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="annotRectWidthMM" select="$annotRectXMaxMM - $annotRectXMinMM"/>
		<xsl:variable name="annotRectHeightMM" select="$annotRectYMaxMM - $annotRectYMinMM"/>
		<!--  resolution of image 1 -->
		<xsl:variable name="image1ResX" select="$maxPixSize div $graphicWidthMM"/>
		<xsl:variable name="image1ResY" select="$maxPixSize div $graphicHeightMM"/>
		<xsl:variable name="image1Res">
			<xsl:choose>
				<xsl:when test="$image1ResX &lt; $image1ResY"><xsl:value-of select="$image1ResX"/></xsl:when>
				<xsl:otherwise><xsl:value-of select="$image1ResY"/></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<!--  calculate image 2 rect with margins -->
		<xsl:variable name="zoomRectMarginXMinMM" select="$annotRectWidthMM * $zoomRectMarginFraction"/>
		<xsl:variable name="zoomRectMarginYMinMM" select="$annotRectHeightMM * $zoomRectMarginFraction"/>
		<xsl:variable name="zoomRectMarginMinMM"> <!-- choose the largest margin -->
			<xsl:choose>
				<xsl:when test="$zoomRectMarginXMinMM &lt; $zoomRectMarginYMinMM"><xsl:value-of select="$zoomRectMarginYMinMM"/></xsl:when>
				<xsl:otherwise><xsl:value-of select="$zoomRectMarginXMinMM"/></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="zoomRectWidthMinMM" select="$annotRectWidthMM + 2 * $zoomRectMarginMinMM"/>
		<xsl:variable name="zoomRectHeightMinMM" select="$annotRectHeightMM + 2 * $zoomRectMarginMinMM"/>
		<!--  resolution of image 2 -->
		<xsl:variable name="image2ResX" select="$maxPixSize div $zoomRectWidthMinMM"/>
		<xsl:variable name="image2ResY" select="$maxPixSize div $zoomRectHeightMinMM"/>
		<xsl:variable name="image2ResMax">
			<xsl:choose>
				<xsl:when test="$image2ResX &lt; $image2ResY"><xsl:value-of select="$image2ResX"/></xsl:when>
				<xsl:otherwise><xsl:value-of select="$image2ResY"/></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="image2Res"> <!-- limit resolution of image 2 -->
			<xsl:choose>
				<xsl:when test="$image2ResMax &lt; $maxRes"><xsl:value-of select="$image2ResMax"/></xsl:when>
				<xsl:otherwise><xsl:value-of select="$maxRes"/></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="zoomRectWidthMM" select="$maxPixSize div $image2Res"/>
		<xsl:variable name="zoomRectHeightMM" select="$maxPixSize div $image2Res"/>
		<xsl:variable name="zoomRectMarginXMM" select="($zoomRectWidthMM - $annotRectXMaxMM + $annotRectXMinMM) div 2"/>
		<xsl:variable name="zoomRectMarginYMM" select="($zoomRectHeightMM - $annotRectYMaxMM + $annotRectYMinMM) div 2"/>
		<xsl:variable name="zoomRectXMinMM" select="$annotRectXMinMM - $zoomRectMarginXMM"/> <!-- unbounded -->
		<xsl:variable name="zoomRectYMinMM" select="$annotRectYMinMM - $zoomRectMarginYMM"/> <!-- unbounded -->
		<xsl:variable name="zoomRectXMaxMM" select="$annotRectXMaxMM + $zoomRectMarginXMM"/> <!-- unbounded -->
		<xsl:variable name="zoomRectYMaxMM" select="$annotRectYMaxMM + $zoomRectMarginYMM"/> <!-- unbounded -->

		<xsl:variable name="image1RectCompensation">
			<xsl:choose>
				<xsl:when test="(name(.) = 'text') and ($detailedThumbnailSrc)"><xsl:value-of select="10 * (1 + $zoomRectMarginFraction + $zoomRectMarginFraction)" /></xsl:when>
				<xsl:otherwise><xsl:value-of select="0" /></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<xsl:variable name="image1MarginX" select="($maxPixSize - ($graphicWidthMM * $image1Res)) div 2.0"/>
		<xsl:variable name="image1MarginY" select="($maxPixSize - ($graphicHeightMM * $image1Res)) div 2.0"/>
		<xsl:variable name="image1RectXMin" select="round($image1MarginX + (($zoomRectXMinMM - $image1RectCompensation) * $image1Res))"/>
		<xsl:variable name="image1RectYMin" select="round($image1MarginY + (($zoomRectYMinMM - $image1RectCompensation) * $image1Res))"/>
		<xsl:variable name="image1RectXMax" select="round($image1MarginX + (($zoomRectXMaxMM + $image1RectCompensation) * $image1Res))"/>
		<xsl:variable name="image1RectYMax" select="round($image1MarginY + (($zoomRectYMaxMM + $image1RectCompensation) * $image1Res))"/>

		<xsl:variable name="srcUrl2">
		
		<xsl:choose>
			<xsl:when test="$detailedThumbnailSrc">
				<xsl:value-of select="$detailedThumbnailSrc"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="concat('DownloadViewerThumbnail.jsp;jsessionid=',$sessionID,'?docversionid=',$selectedVersionID,'&amp;x1=',$zoomRectXMinMM,'&amp;y1=',$zoomRectYMinMM,'&amp;x2=',$zoomRectXMaxMM,'&amp;y2=',$zoomRectYMaxMM,'&amp;res=',$image2Res,'&amp;pageno=',$pageIndex,'&amp;ajax=1')"/>
			</xsl:otherwise>
		</xsl:choose>
		</xsl:variable>

		<xsl:variable name="image2RectXMin" select="round(($annotRectXMinMM - $zoomRectXMinMM) * $image2Res)"/>
		<xsl:variable name="image2RectYMin" select="round(($annotRectYMinMM - $zoomRectYMinMM) * $image2Res)"/>
		<xsl:variable name="image2RectXMax" select="round(($annotRectXMaxMM - $zoomRectXMinMM) * $image2Res)"/>
		<xsl:variable name="image2RectYMax" select="round(($annotRectYMaxMM - $zoomRectYMinMM) * $image2Res)"/>
		
		<xsl:variable name="image2Pt1X" select="round(($annotRect1MM - $zoomRectXMinMM) * $image2Res)"/>
		<xsl:variable name="image2Pt1Y" select="round(($annotRect4MM - $zoomRectYMinMM) * $image2Res)"/>
		<xsl:variable name="image2Pt2X" select="round(($annotRect3MM - $zoomRectXMinMM) * $image2Res)"/>
		<xsl:variable name="image2Pt2Y" select="round(($annotRect2MM - $zoomRectYMinMM) * $image2Res)"/>
		
		<xsl:if test="$debug = 1">
			<td class="darktext_darklink_11">
				pageIndex=<xsl:value-of select="$pageIndex"/>,
				trimmedHeightMM=<xsl:value-of select="$trimmedHeightMM"/>,
				trimmedWidthMM=<xsl:value-of select="$trimmedWidthMM"/>,
				graphicWidthMM=<xsl:value-of select="$graphicWidthMM"/>,
				graphicHeightMM=<xsl:value-of select="$graphicHeightMM"/>,
				graphicMarginTopMM=<xsl:value-of select="$graphicMarginTopMM"/>,
				graphicMarginLeftMM=<xsl:value-of select="$graphicMarginLeftMM"/>,
				graphicMarginBottomMM=<xsl:value-of select="$graphicMarginBottomMM"/>,
				graphicMarginRightMM=<xsl:value-of select="$graphicMarginRightMM"/>,
				annotRect1MM=<xsl:value-of select="$annotRect1MM"/>,
				annotRect2MM=<xsl:value-of select="$annotRect2MM"/>,
				annotRect3MM=<xsl:value-of select="$annotRect3MM"/>,
				annotRect4MM=<xsl:value-of select="$annotRect4MM"/>,
				annotRectXMinMM=<xsl:value-of select="$annotRectXMinMM"/>,
				annotRectYMinMM=<xsl:value-of select="$annotRectYMinMM"/>,
				annotRectXMaxMM=<xsl:value-of select="$annotRectXMaxMM"/>,
				annotRectYMaxMM=<xsl:value-of select="$annotRectYMaxMM"/>,
				zoomRectXMinMM=<xsl:value-of select="$zoomRectXMinMM"/>,
				zoomRectYMinMM=<xsl:value-of select="$zoomRectYMinMM"/>,
				zoomRectXMaxMM=<xsl:value-of select="$zoomRectXMaxMM"/>,
				zoomRectYMaxMM=<xsl:value-of select="$zoomRectYMaxMM"/>,
				image1Res=<xsl:value-of select="$image1Res"/>,
				image1MarginX=<xsl:value-of select="$image1MarginX"/>,
				image1MarginY=<xsl:value-of select="$image1MarginY"/>,
				image1RectXMin=<xsl:value-of select="$image1RectXMin"/>,
				image1RectYMin=<xsl:value-of select="$image1RectYMin"/>,
				image1RectXMax=<xsl:value-of select="$image1RectXMax"/>,
				image1RectYMax=<xsl:value-of select="$image1RectYMax"/>,
				zoomRectMarginXMinMM=<xsl:value-of select="$zoomRectMarginXMinMM"/>,
				zoomRectMarginYMinMM=<xsl:value-of select="$zoomRectMarginYMinMM"/>,
				zoomRectMarginMinMM=<xsl:value-of select="$zoomRectMarginMinMM"/>,
				zoomRectWidthMinMM=<xsl:value-of select="$zoomRectWidthMinMM"/>,
				zoomRectHeightMinMM=<xsl:value-of select="$zoomRectHeightMinMM"/>,
				image2ResX=<xsl:value-of select="$image2ResX"/>,
				image2ResY=<xsl:value-of select="$image2ResY"/>,
				image2Res=<xsl:value-of select="$image2Res"/>,
				color=<xsl:value-of select="./@color"/>,
			</td>
		</xsl:if>
		<xsl:if test="($reportStyle = 1 or $reportStyle = 2)">
			<xsl:variable name="tdId" select="concat('tdid',./@name,'2')"/>
			<td class="darktext_darklink_11" id="{$tdId}">
			<div style="position:relative;height: {$maxPixSize}px; width: {$maxPixSize}px">
				<xsl:variable name="canvasId" select="concat('canvasid',./@name,'2')"/>
				<xsl:variable name="imageId" select="concat('imageid',./@name,'2')"/>
				<xsl:variable name="color">
					<xsl:choose>
						<xsl:when test="$userColors = 1"><xsl:value-of select="./@color"/></xsl:when>
						<xsl:otherwise><xsl:value-of select="'#FF0000'"/></xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<canvas id="{$canvasId}" style="position: absolute; left: 0px;border: 1px solid #DFDFDF;" width="{$maxPixSize}" height="{$maxPixSize}" />
				<script type="text/javascript">
				(function(){
					var canvasid='<xsl:value-of select="$canvasId"/>';
					var c=document.getElementById(canvasid);
					if (c.getContext &amp;&amp; c.getContext("2d")) { <!-- canvas is supported  -->
						var ctx=c.getContext("2d");
						ctx.font="10px Arial";
						ctx.fillText("<xsl:value-of select="Lang:getStr(&lk;, 'LOADINGINPROGRESS')"/>",5,15);
						var image = new Image();
						image.src = '<xsl:value-of select="$srcUrl2"/>';
						image.width = <xsl:value-of select="$maxPixSize"/>
						image.height = <xsl:value-of select="$maxPixSize"/>
						image.onload = function() {

							var canvasid='<xsl:value-of select="$canvasId"/>';
							var c=document.getElementById(canvasid);
							var ctx=c.getContext("2d");
							<xsl:if test="not((name(.) = 'text') and ($userColors = 1))"> <!-- here we will first use the canvas to change the color of the note icon -->
								ctx.clearRect(0,0,400,400);							
								c.parentElement.insertBefore(image, c);
							</xsl:if>
							ctx.strokeStyle='<xsl:value-of select="$color"/>';
							ctx.lineWidth = 2;
						<xsl:choose>
							<xsl:when test="name(.) = 'square'">
								ctx.strokeRect(<xsl:value-of select="$image2RectXMin"/>,<xsl:value-of select="$image2RectYMin"/>,<xsl:value-of select="$image2RectXMax - $image2RectXMin"/>,<xsl:value-of select="$image2RectYMax - $image2RectYMin"/>);
							</xsl:when>
							<xsl:when test="name(.) = 'circle'">
								ctx.save();
								ctx.translate(<xsl:value-of select="($image2RectXMin + $image2RectXMax) div 2"/>,<xsl:value-of select="($image2RectYMin + $image2RectYMax) div 2"/>,<xsl:value-of select="$image2RectXMax - $image2RectXMin"/>,0, 2*Math.PI);
								ctx.scale(<xsl:value-of select="($image2RectXMax - $image2RectXMin)"/>,<xsl:value-of select="($image2RectYMax - $image2RectYMin)"/>);
								ctx.beginPath();
								ctx.arc(0,0,0.5,0,2*Math.PI);
								ctx.restore();
								ctx.stroke();
							</xsl:when>
							<xsl:when test="name(.) = 'text'">
								var imageNoteThumbnail = new Image();								
								imageNoteThumbnail.onload = function() {
								<xsl:choose>								
									<xsl:when test="$userColors = 1">
										ctx.drawImage(imageNoteThumbnail,0,50); <!-- Paint lower than Loading... text -->															
										var imageData=ctx.getImageData(0,50,imageNoteThumbnail.width,imageNoteThumbnail.height);		
										var data=imageData.data;						
										ctx.clearRect(0,0,400,400);							
										c.parentElement.insertBefore(image, c);
										var col=parseInt('<xsl:value-of select="concat('0x',substring-after($color,'#'))"/>',16);
   										for(var i = 0, n = data.length; i &lt; n; i += 4) {
											if (data[i]==255 &amp;&amp; data[i + 1]==255 &amp;&amp; data[i + 2]==0 &amp;&amp; data[i + 3]==255) { <!-- replace yellow -->
												data[i]=(col/256)/256;
												data[i+1]=(col/256)%256;
												data[i+2]=col%256;
											}
										}		
										ctx.putImageData(imageData,<xsl:value-of select="$image2RectXMin"/>,<xsl:value-of select="$image2RectYMin"/>);		
																					
									</xsl:when>
									<xsl:otherwise>
										ctx.drawImage(imageNoteThumbnail,<xsl:value-of select="$image2RectXMin"/>,<xsl:value-of select="$image2RectYMin"/>);															
									</xsl:otherwise>
								</xsl:choose>
								};
								imageNoteThumbnail.src = 'images/comment.png';
							</xsl:when>
							<xsl:when test="name(.) = 'ink'">
								<xsl:for-each select="inklist/gesture">
									ctx.beginPath();
									<xsl:call-template name="drawGestureList">
										<xsl:with-param name="graphicMarginLeftMM" select="$graphicMarginLeftMM"/>
										<xsl:with-param name="graphicMarginBottomMM" select="$graphicMarginBottomMM"/>
										<xsl:with-param name="graphicHeightMM" select="$graphicHeightMM"/>
										<xsl:with-param name="zoomRectXMinMM" select="$zoomRectXMinMM"/>
										<xsl:with-param name="zoomRectYMinMM" select="$zoomRectYMinMM"/>
										<xsl:with-param name="imageRes" select="$image2Res"/>
										<xsl:with-param name="gestureList" select="."/>
									</xsl:call-template>								
									ctx.stroke();
								</xsl:for-each>
							</xsl:when>
							<xsl:when test="name(.) = 'line'">
								ctx.beginPath();
								ctx.moveTo(<xsl:value-of select="$image2Pt1X"/>,<xsl:value-of select="$image2Pt1Y"/>);
								ctx.lineTo(<xsl:value-of select="$image2Pt2X"/>,<xsl:value-of select="$image2Pt2Y"/>);
								ctx.stroke();
								ctx.save();
								<xsl:if test="string-length(./@head) + string-length(./@tail) &gt; 0"> <!--  draw arrow head -->
									ctx.translate(<xsl:value-of select="$image2Pt2X"/>,<xsl:value-of select="$image2Pt2Y"/>);
									ctx.rotate(Math.atan2(<xsl:value-of select="$image2Pt2Y - $image2Pt1Y"/>,<xsl:value-of select="$image2Pt2X - $image2Pt1X"/>));
									ctx.beginPath();
									ctx.moveTo(0,0);
									ctx.lineTo(-20,20);
									ctx.moveTo(0,0);
									ctx.lineTo(-20,-20);
									ctx.restore();
									ctx.stroke();
								</xsl:if>
							</xsl:when>
							<xsl:when test="name(.) = 'highlight'">
								ctx.fillStyle="rgba(255,255,0,0.75)";
								ctx.fillRect(<xsl:value-of select="$image2RectXMin"/>,<xsl:value-of select="$image2RectYMin"/>,<xsl:value-of select="$image2RectXMax - $image2RectXMin"/>,<xsl:value-of select="$image2RectYMax - $image2RectYMin"/>);
							</xsl:when>
							<xsl:otherwise></xsl:otherwise>
						</xsl:choose>
						};
					}
					else { <!-- Canvas isn't available. Non-canvas fallback -->
						var tdid='<xsl:value-of select="$tdId"/>';
						var msg='<xsl:call-template name="encodejs"><xsl:with-param name="string" select="Lang:getStr(&lk;,'HTML5NOSUPPORT')"/></xsl:call-template>';
						var cell=document.getElementById(tdid);
						cell.innerHTML=msg;						
					}
					})();
				</script>
				</div>
			</td>
		</xsl:if>
		<xsl:if test="$reportStyle = 2">
			<xsl:variable name="tdId" select="concat('tdid',./@name,'1')"/>
			<td class="darktext_darklink_11" id="{$tdId}">
				<div style="position:relative;height: {$maxPixSize}px; width: {$maxPixSize}px">
				<xsl:variable name="canvasId" select="concat('canvasid',./@name,'1')"/>
				<xsl:variable name="imageId" select="concat('imageid',./@name,'1')"/>
				<canvas id="{$canvasId}" style="position: absolute; left: 0px;border: 1px solid #DFDFDF;" width="{$maxPixSize}" height="{$maxPixSize}" />
				<script type="text/javascript">
				(function(){
					var canvasid='<xsl:value-of select="$canvasId"/>';
					var c=document.getElementById(canvasid);
					if (c.getContext &amp;&amp; c.getContext("2d")) { <!-- canvas is supported  -->
						var ctx=c.getContext("2d");
						ctx.font="10px Arial";
						ctx.fillText("<xsl:value-of select="Lang:getStr(&lk;, 'LOADINGINPROGRESS')"/>",5,15);
						var image = new Image();
						image.src = '<xsl:value-of select="$srcUrl1"/>';
						image.width = <xsl:value-of select="$maxPixSize"/>
						image.height = <xsl:value-of select="$maxPixSize"/>
						
						image.onload = function() {
							var canvasid='<xsl:value-of select="$canvasId"/>';
							var c=document.getElementById(canvasid);
							var ctx=c.getContext("2d");
							ctx.clearRect(0,0,400,400);
							c.parentElement.insertBefore(image, c);
							ctx.fillStyle="rgba(255,0,0,0.75)";
							ctx.fillRect(<xsl:value-of select="$image1RectXMin"/>,<xsl:value-of select="$image1RectYMin"/>,<xsl:value-of select="$image1RectXMax - $image1RectXMin"/>,<xsl:value-of select="$image1RectYMax - $image1RectYMin"/>);
						};
					}
					else { <!-- Canvas isn't available. Non-canvas fallback -->
						var tdid='<xsl:value-of select="$tdId"/>';
						var cell=document.getElementById(tdid);
						cell.innerHTML='';						
					}
					})();
				</script>
				</div>
			</td>
		</xsl:if>
	</xsl:template>
  
	<xsl:template name="pageCount">
		<xsl:choose>
			<xsl:when test="count(/webcenter_page/page_count) &gt; 0"><xsl:value-of select="/webcenter_page/page_count"/></xsl:when>
			<xsl:otherwise><xsl:value-of select="0"/></xsl:otherwise>
		</xsl:choose>		
	</xsl:template>

	<xsl:template name="viewableGraphics">
		<xsl:value-of select="((/webcenter_page/doc_version/doc_task/status_id = '00001_0000000003') or (/webcenter_page/doc_version/doc_task/status_id = '00001_0000000004')) and 
										not(contains(/webcenter_page/doc_version/doc_task/message, 'ESVG')) and
										((count(/webcenter_page/romd/webcenter_graphic_data/graphic_height) &gt; 0) or
										(count(/webcenter_page/romd/webcenter_graphic_data/pageranges/pagerange[index = 0]/graphic_height) &gt; 0))"/>
	</xsl:template>

	<xsl:variable name="viewableGraphics">
			<xsl:call-template name="viewableGraphics"/>
	</xsl:variable>
	
	<xsl:template name="viewableSVG">
		<xsl:value-of select="/webcenter_page/vector_viewfile_type = 'svg'"/>
	</xsl:template>
	
	<xsl:variable name="viewableSVG">	
		<xsl:call-template name="viewableSVG"/>
	</xsl:variable>
	
	<xsl:template name="viewableESVG">
		<xsl:value-of select="/webcenter_page/vector_viewfile_type = 'esvg'"/>
	</xsl:template>
	
	<xsl:variable name="viewableESVG">	
		<xsl:call-template name="viewableESVG"/>
	</xsl:variable>
	
	<xsl:template name="viewableVector">
		<xsl:value-of select="$viewableSVG='true' or $viewableESVG='true'" />
	</xsl:template>
	
	<xsl:variable name="viewableVector">	
		<xsl:call-template name="viewableVector"/>
	</xsl:variable>

	<xsl:template name="viewableVideo">
		<xsl:value-of select="/webcenter_page/romd/metadata/type = '/video/direct-video-url'"/>
	</xsl:template>
	
	<xsl:variable name="viewableVideo">	
		<xsl:call-template name="viewableVideo"/>
	</xsl:variable>
	
	<xsl:template name="hasTimestamp">
		<xsl:choose>
		<xsl:when test="$viewableVideo and /webcenter_page/xfdf/annots/*/@startTime">1</xsl:when>
		<xsl:otherwise>0</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:variable name="hasTimestamp">
		<xsl:call-template name="hasTimestamp" />
	</xsl:variable>
	
	<xsl:template name="viewable3D">
		<xsl:value-of select="/webcenter_page/only3dperspective = '1'"/>
	</xsl:template>
	
	<xsl:variable name="viewable3D">	
		<xsl:call-template name="viewable3D"/>
	</xsl:variable>

	<xsl:template name="reportStyle">
		<xsl:choose>
			<xsl:when test="$viewableGraphics='false' and $viewableVector='false' and $viewableVideo='false' and $viewable3D='false'"><xsl:value-of select="0"/></xsl:when>
			<xsl:when test="count(/webcenter_page/report_style) &gt; 0"><xsl:value-of select="/webcenter_page/report_style"/></xsl:when>
			<xsl:otherwise><xsl:value-of select="2"/></xsl:otherwise>
		</xsl:choose>		
	</xsl:template>

	<xsl:template name="maxPixSize">
		<xsl:choose>
			<xsl:when test="count(/webcenter_page/thumbnail_size) &gt; 0"><xsl:value-of select="/webcenter_page/thumbnail_size"/></xsl:when>
			<xsl:otherwise><xsl:value-of select="200"/></xsl:otherwise>
		</xsl:choose>		
	</xsl:template>

	<xsl:template name="userColors">
		<xsl:choose>
			<xsl:when test="count(/webcenter_page/user_colors) &gt; 0"><xsl:value-of select="/webcenter_page/user_colors"/></xsl:when>
			<xsl:otherwise><xsl:value-of select="0"/></xsl:otherwise>
		</xsl:choose>		
	</xsl:template>

	<xsl:template name="reviewState">
		<xsl:choose>
			<xsl:when test="count(/webcenter_page/review_state) &gt; 0"><xsl:value-of select="/webcenter_page/review_state"/></xsl:when>
			<xsl:otherwise><xsl:value-of select="0"/></xsl:otherwise>
		</xsl:choose>		
	</xsl:template>

	<xsl:template name="userName">
		<xsl:choose>
			<xsl:when test="count(/webcenter_page/user_name) &gt; 0"><xsl:value-of select="/webcenter_page/user_name"/></xsl:when>
			<xsl:otherwise><xsl:value-of select="0"/></xsl:otherwise>
		</xsl:choose>		
	</xsl:template>
	
	<xsl:template name="showUser">
		<xsl:choose>
			<xsl:when test="count(/webcenter_page/show_users) &gt; 0"><xsl:value-of select="/webcenter_page/show_users"/></xsl:when>
			<xsl:otherwise><xsl:value-of select="0"/></xsl:otherwise>
		</xsl:choose>		
	</xsl:template>

	<xsl:template name="isPrinting">
		<xsl:choose>
			<xsl:when test="count(/webcenter_page/is_printing) &gt; 0"><xsl:value-of select="/webcenter_page/is_printing"/></xsl:when>
			<xsl:otherwise><xsl:value-of select="0"/></xsl:otherwise>
		</xsl:choose>		
	</xsl:template>

	<xsl:template name="debug">
		<xsl:choose>
			<xsl:when test="count(/webcenter_page/debug) &gt; 0"><xsl:value-of select="/webcenter_page/debug"/></xsl:when>
			<xsl:otherwise><xsl:value-of select="0"/></xsl:otherwise>
		</xsl:choose>		
	</xsl:template>

	<xsl:template name="sessionID">
		<xsl:choose>
			<xsl:when test="count(/webcenter_page/session_id) &gt; 0"><xsl:value-of select="/webcenter_page/session_id"/></xsl:when>
			<xsl:otherwise><xsl:value-of select="0"/></xsl:otherwise>
		</xsl:choose>		
	</xsl:template>
	
	<xsl:template name="secondsToUserFriendlyString">
		<xsl:param name="s" />
		
		<xsl:variable name="minutes" select="floor(floor($s) div 60)" ></xsl:variable>
		<xsl:variable name="seconds" select="floor($s) - $minutes * 60" />
		<xsl:variable name="milliseconds" select="floor($s * 1000) mod 1000" />
		
		<xsl:variable name="userFriendlyMinutes">
			<xsl:choose>
				<xsl:when test="$minutes &lt; 10">0<xsl:value-of select="$minutes" /></xsl:when>
				<xsl:otherwise><xsl:value-of select="$minutes" /></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>		
		
		<xsl:variable name="userFriendlySeconds">
			<xsl:choose>
				<xsl:when test="$seconds &lt; 10">0<xsl:value-of select="$seconds" /></xsl:when>
				<xsl:otherwise><xsl:value-of select="$seconds" /></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>		
		<xsl:variable name="userFriendlyMilliseconds">
			<xsl:choose>
				<xsl:when test="$milliseconds &lt; 10">00<xsl:value-of select="$milliseconds" /></xsl:when>
				<xsl:when test="$milliseconds &lt; 100">0<xsl:value-of select="$milliseconds" /></xsl:when>
				<xsl:otherwise><xsl:value-of select="$milliseconds" /></xsl:otherwise>			
			</xsl:choose>
		</xsl:variable>
		
		<xsl:value-of select="$userFriendlyMinutes"/>:<xsl:value-of select="$userFriendlySeconds"/>,<xsl:value-of select="$userFriendlyMilliseconds"/>
	</xsl:template>

	<xsl:template name="drawGestureList">
		<xsl:param name="graphicMarginLeftMM"/>
		<xsl:param name="graphicMarginBottomMM"/>
		<xsl:param name="graphicHeightMM"/>
		<xsl:param name="zoomRectXMinMM"/>
		<xsl:param name="zoomRectYMinMM"/>
		<xsl:param name="imageRes"/>
		<xsl:param name="gestureList"/>
		<xsl:param name="firstPoint" select="true()"/>
		
		<xsl:variable name="startX" select="substring-before($gestureList,',')"/>
		<xsl:variable name="startY">
			<xsl:choose>
				<xsl:when test="contains($gestureList, ';')"><xsl:value-of select="substring-before(substring-after($gestureList,','),';')"/></xsl:when>
				<xsl:otherwise><xsl:value-of select="substring-after($gestureList,',')"/></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="startXMM" select="$graphicMarginLeftMM + (($startX * 25.4) div 72.0)"/>
		<xsl:variable name="startYMM" select="$graphicHeightMM - $graphicMarginBottomMM - (($startY * 25.4) div 72.0)"/>
		<xsl:variable name="imagePtX" select="round(($startXMM - $zoomRectXMinMM) * $imageRes)"/>
		<xsl:variable name="imagePtY" select="round(($startYMM - $zoomRectYMinMM) * $imageRes)"/>
		<xsl:variable name="rest" select="substring-after($gestureList,';')"/>
		
		<xsl:choose>
			<xsl:when test="$firstPoint = true()">ctx.moveTo(<xsl:value-of select="$imagePtX"/>,<xsl:value-of select="$imagePtY"/>);</xsl:when>
			<xsl:otherwise>ctx.lineTo(<xsl:value-of select="$imagePtX"/>,<xsl:value-of select="$imagePtY"/>);</xsl:otherwise>						
		</xsl:choose>
		
		<xsl:if test="string-length($rest) &gt; 0">
			<xsl:call-template name="drawGestureList">
				<xsl:with-param name="graphicMarginLeftMM" select="$graphicMarginLeftMM"/>
				<xsl:with-param name="graphicMarginBottomMM" select="$graphicMarginBottomMM"/>
				<xsl:with-param name="graphicHeightMM" select="$graphicHeightMM"/>
				<xsl:with-param name="zoomRectXMinMM" select="$zoomRectXMinMM"/>
				<xsl:with-param name="zoomRectYMinMM" select="$zoomRectYMinMM"/>
				<xsl:with-param name="imageRes" select="$imageRes"/>
				<xsl:with-param name="gestureList" select="$rest"/>
				<xsl:with-param name="firstPoint" select="false()"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>

</xsl:stylesheet>
